@@ -1,7 +1,7 @@
 #! /bin/sh
 
-if [ -e /opt-share/etc/profile.ant ] ; then
-    . /opt-share/etc/profile.ant
+if [ -e /usr/local/etc/profile.ant ] ; then
+    . /usr/local/etc/profile.ant
 fi
 
 #    -Dc.compiler.debug=true 
@@ -13,13 +13,13 @@ fi
 # Force OSX SDK 10.6, if desired
 # export SDKROOT=macosx10.6
 
-JAVA_HOME=`/usr/libexec/java_home -version 1.8`
+JAVA_HOME=`/usr/libexec/java_home -version 17`
 PATH=$JAVA_HOME/bin:$PATH
 export JAVA_HOME PATH
 
-export SOURCE_LEVEL=1.6
-export TARGET_LEVEL=1.6
-export TARGET_RT_JAR=/opt-share/jre1.6.0_30/lib/rt.jar
+export SOURCE_LEVEL=1.8
+export TARGET_LEVEL=1.8
+export TARGET_RT_JAR=/usr/local/jre1.8.0_212/lib/rt.jar
 
 #export JOGAMP_JAR_CODEBASE="Codebase: *.jogamp.org"
 export JOGAMP_JAR_CODEBASE="Codebase: *.goethel.localnet"
