@@ -39,6 +39,8 @@
  */
 package com.jogamp.common.nio;
 
+import java.lang.reflect.Field;
+import java.lang.reflect.Method;
 import java.nio.Buffer;
 import java.nio.ByteBuffer;
 import java.nio.ByteOrder;
@@ -48,9 +50,17 @@ import java.nio.FloatBuffer;
 import java.nio.IntBuffer;
 import java.nio.LongBuffer;
 import java.nio.ShortBuffer;
+import java.security.PrivilegedAction;
 
+import com.jogamp.common.ExceptionUtils;
+import com.jogamp.common.util.ReflectionUtil;
+import com.jogamp.common.util.SecurityUtil;
+import com.jogamp.common.util.UnsafeUtil;
 import com.jogamp.common.util.ValueConv;
 
+import jogamp.common.Debug;
+import jogamp.common.os.PlatformPropsImpl;
+
 /**
  * Utility methods allowing easy {@link java.nio.Buffer} manipulations.
  *
@@ -60,6 +70,11 @@ import com.jogamp.common.util.ValueConv;
  */
 public class Buffers {
 
+    static final boolean DEBUG;
+    static {
+        DEBUG = Debug.debug("Buffers");
+    }
+
     public static final int SIZEOF_BYTE     = 1;
     public static final int SIZEOF_SHORT    = 2;
     public static final int SIZEOF_CHAR     = 2;
@@ -1150,4 +1165,82 @@ public class Buffers {
         return sb;
     }
 
+    /**
+     * Access to NIO {@link sun.misc.Cleaner}, allowing caller to deterministically clean a given {@link sun.nio.ch.DirectBuffer}.
+     */
+    public static class Cleaner {
+        private static final Method mbbCleaner;
+        private static final Method cClean;
+        /** OK to be lazy on thread synchronization, just for early out **/
+        private static volatile boolean cleanerError;
+        static {
+            final Method[] _mbbCleaner = { null };
+            final Method[] _cClean = { null };
+            final boolean hasCleaner;
+            if( SecurityUtil.doPrivileged(new PrivilegedAction<Boolean>() {
+                @Override
+                public Boolean run() {
+                    try {
+                        if( PlatformPropsImpl.JAVA_9 ) {
+                            return UnsafeUtil.hasInvokeCleaner();
+                        } else {
+                            _mbbCleaner[0] = ReflectionUtil.getMethod("sun.nio.ch.DirectBuffer", "cleaner", null, Buffers.class.getClassLoader());
+                            _mbbCleaner[0].setAccessible(true);
+                            final Class<?> cleanerType = _mbbCleaner[0].getReturnType();
+                            // Java >= 9: jdk.internal.ref.Cleaner (NOT accessible!)
+                            //            "Unable to make public void jdk.internal.ref.Cleaner.clean() accessible:
+                            //             module java.base does not "exports jdk.internal.ref" to unnamed module"
+                            // Java <= 8: sun.misc.Cleaner OK
+                            _cClean[0] = cleanerType.getMethod("clean");
+                            _cClean[0].setAccessible(true);
+                            return Boolean.TRUE;
+                        }
+                    } catch(final Throwable t) {
+                        if( DEBUG ) {
+                            ExceptionUtils.dumpThrowable("Buffers", t);
+                        }
+                        return Boolean.FALSE;
+                    } } } ).booleanValue() ) {
+                mbbCleaner = _mbbCleaner[0];
+                cClean = _cClean[0];
+                hasCleaner = PlatformPropsImpl.JAVA_9 || ( null != mbbCleaner && null != cClean );
+            } else {
+                mbbCleaner = null;
+                cClean = null;
+                hasCleaner = false;
+            }
+            cleanerError = !hasCleaner;
+            if( DEBUG ) {
+                System.err.print("Buffers.Cleaner.init: hasCleaner: "+hasCleaner+", cleanerError "+cleanerError);
+                if( null != mbbCleaner ) {
+                    System.err.print(", using Cleaner class: "+mbbCleaner.getReturnType().getName());
+                }
+                System.err.println();
+            }
+        }
+        /**
+         * If {@code b} is an direct NIO buffer, i.e {@link sun.nio.ch.DirectBuffer},
+         * calls it's {@link sun.misc.Cleaner} instance {@code clean()} method once.
+         * @return {@code true} if successful, otherwise {@code false}.
+         */
+        public static boolean clean(final ByteBuffer bb) {
+            if( cleanerError || !bb.isDirect() ) {
+                return false;
+            }
+            try {
+                if( PlatformPropsImpl.JAVA_9 ) {
+                    UnsafeUtil.invokeCleaner(bb);
+                } else {
+                    cClean.invoke(mbbCleaner.invoke(bb));
+                }
+                return true;
+            } catch(final Throwable t) {
+                cleanerError = true;
+                if( DEBUG ) {
+                    ExceptionUtils.dumpThrowable("Buffers", t);
+                }
+                return false;
+            }
+        }
+    }
 }
