@@ -28,7 +28,6 @@
 
 package com.jogamp.common.os;
 
-import java.security.AccessController;
 import java.security.PrivilegedAction;
 import java.util.concurrent.TimeUnit;
 
@@ -37,6 +36,7 @@ import com.jogamp.common.net.Uri;
 import com.jogamp.common.util.JarUtil;
 import com.jogamp.common.util.PropertyAccess;
 import com.jogamp.common.util.ReflectionUtil;
+import com.jogamp.common.util.SecurityUtil;
 import com.jogamp.common.util.VersionNumber;
 import com.jogamp.common.util.cache.TempJarCache;
 
@@ -58,7 +58,7 @@ import jogamp.common.os.PlatformPropsImpl;
 public class Platform extends PlatformPropsImpl {
 
     public enum OSType {
-        LINUX, FREEBSD, ANDROID, MACOS, SUNOS, HPUX, WINDOWS, OPENKODE;
+        LINUX, FREEBSD, ANDROID, MACOS, SUNOS, HPUX, WINDOWS, OPENKODE, IOS;
     }
 
     public enum CPUFamily {
@@ -255,8 +255,11 @@ public class Platform extends PlatformPropsImpl {
 
     private static final String useTempJarCachePropName = "jogamp.gluegen.UseTempJarCache";
 
-    /** fixed basename of JAR file and native library */
-    private static final String libBaseName = "gluegen-rt";
+    /**
+     * Fixed basename of JAR file and native library.
+     * Dash replaced by underscore to allow static linkage via JEP 178.
+     */
+    private static final String libBaseName = "gluegen_rt";
 
     //
     // static initialization order:
@@ -284,7 +287,7 @@ public class Platform extends PlatformPropsImpl {
         final boolean[] _USE_TEMP_JAR_CACHE = new boolean[] { false };
         final boolean[] _AWT_AVAILABLE = new boolean[] { false };
 
-        AccessController.doPrivileged(new PrivilegedAction<Object>() {
+        SecurityUtil.doPrivileged(new PrivilegedAction<Object>() {
             @Override
             public Object run() {
 
@@ -302,11 +305,12 @@ public class Platform extends PlatformPropsImpl {
                 }
                 _isRunningFromJarURL[0] = null != platformClassJarURI;
 
-                _USE_TEMP_JAR_CACHE[0] = ( OS_TYPE != OSType.ANDROID ) && ( null != platformClassJarURI ) &&
+                _USE_TEMP_JAR_CACHE[0] = ( OS_TYPE != OSType.ANDROID ) && ( OS_TYPE != OSType.IOS ) &&
+                                         ( null != platformClassJarURI ) &&
                                          PropertyAccess.getBooleanProperty(useTempJarCachePropName, true, true);
 
                 // load GluegenRT native library
-                if(_USE_TEMP_JAR_CACHE[0] && TempJarCache.initSingleton()) {
+                if(_USE_TEMP_JAR_CACHE[0] && TempJarCache.initSingleton() && TempJarCache.isInitialized(true) ) {
                     try {
                         JNILibLoaderBase.addNativeJarLibs(new Class<?>[] { jogamp.common.Debug.class }, null);
                     } catch (final Exception e0) {
@@ -317,7 +321,7 @@ public class Platform extends PlatformPropsImpl {
                 DynamicLibraryBundle.GlueJNILibLoader.loadLibrary(libBaseName, false, cl);
 
                 // JVM bug workaround
-                JVMUtil.initSingleton(); // requires gluegen-rt, one-time init.
+                JVMUtil.initSingleton(); // requires gluegen_rt, one-time init.
 
                 // AWT Headless determination
                 if( !PropertyAccess.getBooleanProperty("java.awt.headless", true) &&
@@ -350,7 +354,7 @@ public class Platform extends PlatformPropsImpl {
     }
 
     /**
-     * kick off static initialization of <i>platform property information</i> and <i>native gluegen-rt lib loading</i>
+     * kick off static initialization of <i>platform property information</i> and <i>native gluegen_rt lib loading</i>
      */
     public static void initSingleton() { }
 
