@@ -412,20 +412,6 @@ public class JarUtil {
         return null;
     }
 
-    /**
-     * See {@link #getRelativeOf(Class, com.jogamp.common.net.Uri.Encoded, com.jogamp.common.net.Uri.Encoded)}.
-     * @param classFromJavaJar URI encoded!
-     * @param cutOffInclSubDir URI encoded!
-     * @param relResPath URI encoded!
-     * @return
-     * @throws IllegalArgumentException
-     * @throws IOException
-     * @throws URISyntaxException
-     * @deprecated Use {@link #getRelativeOf(Class, com.jogamp.common.net.Uri.Encoded, com.jogamp.common.net.Uri.Encoded)}.
-     */
-    public static java.net.URI getRelativeOf(final Class<?> classFromJavaJar, final String cutOffInclSubDir, final String relResPath) throws IllegalArgumentException, IOException, URISyntaxException {
-        return getRelativeOf(classFromJavaJar, Uri.Encoded.cast(cutOffInclSubDir), Uri.Encoded.cast(relResPath)).toURI();
-    }
     /**
      * Locates the {@link JarUtil#getJarFileUri(Uri) Jar file Uri} of a given resource
      * relative to a given class's Jar's Uri.
@@ -674,7 +660,7 @@ public class JarUtil {
         // We tolerate UnsatisfiedLinkError (and derived) to solve the chicken and egg problem
         // of loading gluegen's native library.
         // On Safari(OSX), Bug 865, we simply hope the destination folder is executable.
-        if( Platform.OSType.MACOS == Platform.getOSType() ) {
+        if( Platform.OSType.MACOS == Platform.getOSType() || Platform.OSType.IOS == Platform.getOSType() ) {
             final String fileAbsPath = file.getAbsolutePath();
             try {
                 fixNativeLibAttribs(fileAbsPath);
