@@ -85,7 +85,7 @@ import jogamp.common.Debug;
  * @author Michael Bien, et al.
  */
 @SupportedAnnotationTypes(value = {"com.jogamp.gluegen.structgen.CStruct", "com.jogamp.gluegen.structgen.CStructs"})
-@SupportedSourceVersion(SourceVersion.RELEASE_6)
+@SupportedSourceVersion(SourceVersion.RELEASE_11)
 public class CStructAnnotationProcessor extends AbstractProcessor {
     private static final String DEFAULT = "_default_";
     static final boolean DEBUG;
@@ -178,7 +178,10 @@ public class CStructAnnotationProcessor extends AbstractProcessor {
                 System.err.println("CStruct.0: element: "+element+", .simpleName "+element.getSimpleName());
                 System.err.print("CStruct.0: isPackageOrType "+isPackageOrType+", enclElement: "+enclElement);
                 if( !isPackageOrType ) {
-                    System.err.println(", .simpleName "+enclElement.getSimpleName()+", .package "+eltUtils.getPackageOf(enclElement).toString());
+                	if(!enclElement.toString().equals("unnamed module"))
+	                    System.err.println(", .simpleName "+enclElement.getSimpleName()+", .package "+eltUtils.getPackageOf(enclElement).toString());
+                	else
+	                    System.err.println(", .simpleName "+enclElement.getSimpleName()+", .package <unnamed modules have no package>");
                 } else {
                     System.err.println("");
                 }
@@ -246,7 +249,7 @@ public class CStructAnnotationProcessor extends AbstractProcessor {
             writer = new FileWriter(configFile);
             writer.write("Package "+pakage+"\n");
             writer.write("EmitStruct "+structName+"\n");
-            if( finalType != structName ) {
+            if( !useJavaName && (finalType != structName) ) {
                 // We allow renaming the structType to the element's declaredType (FIELD annotation only)
                 writer.write("RenameJavaType " + struct.name()+" " + declaredType +"\n");
             }
