@@ -299,8 +299,8 @@ MYAPI MYAPIConfig *  MYAPIENTRY typeTestAnonPointer(const MYAPIConfig * a);
 #define HUGE_VALF_3        ((int) 1e53)
 #define DOUBLE_DEFINE_BRACKETS_3 HUGE_VALF_3
 
-size_t unsigned_size_t_1;
-ptrdiff_t a_signed_pointer_t_1;
+extern size_t unsigned_size_t_1;
+extern ptrdiff_t a_signed_pointer_t_1;
 
 MYAPI int32_t   MYAPIENTRY typeTestInt32T(const int32_t i1, int32_t i2);
 MYAPI uint32_t  MYAPIENTRY typeTestUInt32T(const uint32_t ui1, uint32_t ui2);
@@ -462,8 +462,8 @@ typedef struct {
 
     TK_Context ctx;
 
-    const char modelNameArrayFixedLen[12]; /* 'Hello Array' len=11+1 */
-    const char * modelNamePointerCString;    /* 'Hello CString' len=13+1 */
+    char modelNameArrayFixedLen[12]; /* 'Hello Array' len=11+1 */
+    char * modelNamePointerCString;    /* 'Hello CString' len=13+1 */
     const char * modelNamePointerCustomLen;  /* 'Hello Pointer' len=13+1 */
     const int modelNamePointerCustomLenVal;  /* 13+1 */
 
@@ -495,7 +495,7 @@ typedef struct {
     TK_Context ctx;
 
     char modelNameArrayFixedLen[12]; /* 'Hello Array' len=11+1 */
-    const char * modelNamePointerCString;    /* 'Hello CString' len=13+1 */
+    char * modelNamePointerCString;    /* 'Hello CString' len=13+1 */
     char * modelNamePointerCustomLen;  /* 'Hello Pointer' len=13+1 */
     int modelNamePointerCustomLenVal;  /* 13+1 */
 
